@@ -31,8 +31,7 @@ static gint callback()
 			counter = 0;
 			printf("%4d ms - ", delay);
 			g_timeout_add_full(G_PRIORITY_HIGH, delay, callback, NULL, NULL);
-		}
-		else
+		} else
 			g_main_loop_quit(main_loop);
 
 		return FALSE;
