@@ -2,7 +2,7 @@
  *	libetm-0.4 / misc.h - Copyright (C) Emmanuel Thomas-Maurin 2008-2012
  * 	<manutm007@gmail.com>
  *
- *	- misc functions -
+ *	- Misc functions -
  *
  * 	This program is free software: you can redistribute it and/or modify
  * 	it under the terms of the GNU General Public License as published by
