@@ -48,6 +48,23 @@ const char *get_appdata_dir()
 		return NULL;
 }
 
+/* Return NULL if error */
+const char *get_appdata_dir_w()
+{
+	static WCHAR	appdata_dir[MAX_PATH + 1];
+	static int	i = 0;
+
+	if (i == 0) {
+		i++;
+		if (SHGetFolderPathW(NULL, CSIDL_APPDATA, NULL, 0, appdata_dir) != S_OK)
+			i++;
+	}
+	if (i == 1)
+		return (const char *)appdata_dir;
+	else
+		return NULL;
+}
+
 /* Return NULL if error */
 const char *get_progfiles_dir()
 {
