@@ -21,21 +21,19 @@
 
 #define APP_NAME		"Tickr"
 #define APP_CMD			"tickr"
-#define APP_VERSION_NUMBER	"0.6.3"
+#define APP_VERSION_NUMBER	"0.6.4"
 #define WEBSITE_URL		"http://www.newsrssticker.com"
-#define SUPPORT_URL		WEBSITE_URL"/help.php"
-#define DOWNLOAD_URL		WEBSITE_URL"/download.php"
+#define SUPPORT_URL		WEBSITE_URL "/help.php"
+#define DOWNLOAD_URL		WEBSITE_URL "/download.php"
 #define SUPPORT_EMAIL_ADDR	"manu@newsrssticker.com"
-#define CHECK4UPDATES_URL	WEBSITE_URL"/app_version_visible.php"
+#define CHECK4UPDATES_URL	WEBSITE_URL "/app_version_visible.php"
 #define CHECK4UPDATES_ID_STR	"LSVN="	/* Stands for 'Last Stable Version Number = ' */
 
 #define _GNU_SOURCE
 #define _ISOC99_SOURCE
 
-/*#define DOUBLE_LINE_TICKER*/		/* NEW and experimental/unstable */
-
 #define VERBOSE_OUTPUT
-/*#define DEBUG_OUTPUT*/		/* Actually never used so far */
+/*#define DEBUG_OUTPUT*/
 
 /* For info_win_wait(..., timeout) */
 /*#define INFO_WIN_WAIT_POS	GTK_WIN_POS_CENTER*/	/* Same as for info_win() */
@@ -46,12 +44,10 @@
 #define CONNECT_FAIL_MAX	5
 #define CONNECT_FAIL_TIMEOUT	1
 
-/* To avoid confusion.
- * We must make sure this value doesn't conflict with any other user-defined GTK_RESPONSE_STH
- * (at the moment, only one enum in tickr_feedpicker.c.) */
-#define GTK_RESPONSE_CANCEL_CLOSE	100	/* Predefined GTK_RESPONSE_ are < 0 */
-
-/* For correctness sake, 'uri' should be used instead of 'url'. */
+/* To avoid confusion, we must make sure this value doesn't conflict with
+ * any other user-defined GTK_RESPONSE_STH (at the moment, only one enum
+ * in tickr_feedpicker.c.) */
+#define GTK_RESPONSE_CANCEL_CLOSE	100	/* All predefined GTK_RESPONSE_ are < 0 */
 
 #include <stdio.h>
 #include <string.h>
@@ -107,13 +103,12 @@
 #define OPTION_NAME_MAXLEN	31
 #define OPTION_VALUE_MAXLEN	MAX(MAX(FILE_NAME_MAXLEN, FONT_MAXLEN), DELIMITER_MAXLEN)
 #define OPTION_MAXLEN		OPTION_NAME_MAXLEN + OPTION_VALUE_MAXLEN + 4	/* -name="value" */
-#define N_OPTION_MAX		64	/* Max number of options */
+#define N_OPTION_MAX		128	/* Max number of options */
 #define N_URL_MAX		1024	/* Max number of url's */
 #define NFEEDLINKANDOFFSETMAX	256	/* Max number of "open-able" links per feed */
-/*#define LINK_TAG_CHAR		'^'*/	/* ascii 5E - char used internally for links, removed from feed text */
 #define LINK_TAG_CHAR		((char)(1))	/* char (ascii 01) used internally for item links, removed from feed text */
 #define ITEM_TITLE_TAG_CHAR	((char)(2))	/* char (ascii 02) used internally for item titles, --- */
-#define ITEM_DES_TAG_CHAR	((char)(3))	/* char (ascii 03) used internally for item descrptions, --- */
+#define ITEM_DES_TAG_CHAR	((char)(3))	/* char (ascii 03) used internally for item descriptions, --- */
 
 #define TMPSTR_SIZE		(2 * 1024 - 1)	/* Used for most tmp strings - must be large enough */
 #ifndef G_OS_WIN32
@@ -132,12 +127,12 @@
 
 /* Make sure this stuff is robust enough */
 #define XPIXMAP_MAXWIDTH	(32 * 1024 - 1)	/* 32 K - 1 = max supported width for xpixmaps
-						 * (not 64 k - 1 as sometimes uncorrectly specified.)
+						 * (not 64 k - 1 as sometimes uncorrectly mentioned.)
 						 */
 #define LINE_MAXLEN		128	/* Max length of a single line (see tickr_render.c) */
 #define WORD_MAXLEN		32	/* Max length of a word that won't get cut off */
 #if (LINE_MAXLEN <= WORD_MAXLEN)
-# error LINE_MAXLEN must be > WORD_MAXLEN
+# error "LINE_MAXLEN must be > WORD_MAXLEN"
 #endif
 #define FONT_MAXSIZE		200
 
@@ -155,15 +150,15 @@
  *			C:\...\Application Data\APP_NAME\
  */
 #ifndef G_OS_WIN32
-# define TICKR_DIR_NAME		"."APP_CMD
+# define TICKR_DIR_NAME		"." APP_CMD
 #else
 # define TICKR_DIR_NAME		APP_NAME
 #endif
-#define CONFIG_FILE		APP_CMD"-conf"
-#define URL_LIST_FILE		APP_CMD"-url-list"
-#define RESOURCE_DUMP		APP_CMD"-resrc-dump.xml"
-#define XML_DUMP		APP_CMD"-xml-dump"
-#define XML_DUMP_EXTRA		APP_CMD"-xml-dump-extra"
+#define CONFIG_FILE		APP_CMD "-conf"
+#define URL_LIST_FILE		APP_CMD "-url-list"
+#define RESOURCE_DUMP		APP_CMD "-resrc-dump.xml"
+#define XML_DUMP		APP_CMD "-xml-dump"
+#define XML_DUMP_EXTRA		APP_CMD "-xml-dump-extra"
 #define TMP1			"tmp1"
 #define TMP2			"tmp2"
 #ifndef G_OS_WIN32
@@ -178,14 +173,14 @@
 # define STDERR_FILENAME2	"stderr2.txt"
 #endif
 #ifndef G_OS_WIN32
-# define INSTALL_PATH		"/usr/share/"APP_CMD
-# define IMAGES_PATH		INSTALL_PATH"/pixmaps"
+# define INSTALL_PATH		"/usr/share/" APP_CMD
+# define IMAGES_PATH		INSTALL_PATH "/pixmaps"
 #else
-# define IMAGES_PATH		APP_NAME	/* actually not a path but a dir name */
+# define IMAGES_PATH		APP_NAME	/* Actually not a path but a dir name */
 #endif
-#define TICKR_ICON		APP_CMD"-icon.png"
-#define TICKR_LOGO		APP_CMD"-logo.png"
-#define RSS_ICON		APP_CMD"-rss-icon.png"
+#define TICKR_ICON		APP_CMD "-icon.png"
+#define TICKR_LOGO		APP_CMD "-logo.png"
+#define RSS_ICON		APP_CMD "-rss-icon.png"
 
 /* Default config values */
 #define DELAY			8
@@ -196,14 +191,19 @@
 # define FONTNAME		"Arial Unicode MS"
 #endif
 #define FONTSIZE		"14"
-#define FGCOLOR			"#ffffffff"	/* White */
-#define BGCOLOR			"#36516240"	/* Some translucent blue */
+#define FGCOLOR			"#ffffffff"
+#define BGCOLOR			"#40404080"
+#define SETGRADIENTBG		'y'
+#define BGCOLOR2		"#20202080"
+#define DISABLESCREENLIMITS	'n'
 #define WIN_X			0
 #define WIN_Y			0
-#define WIN_W			1024	/* Unused, we use get_ticker_env()->screen_w instead */
+/*#define WIN_W			1024	Unused, we use get_ticker_env()->screen_w instead */
 #define WIN_H			0	/* If = 0, determined by font size */
+#define WIN_MAX_Y		5000
+#define WIN_MAX_W		10000
 #define WINDEC			'n'
-#define ALWAYSONTOP		'n'	/* Changed to no */
+#define ALWAYSONTOP		'n'
 #ifndef G_OS_WIN32
 # define WINTRANSPARENCY	1.0
 #else
@@ -216,17 +216,17 @@
 #define SHADOWOFFSET_Y		2
 #define SHADOWFX		2
 #define LINEDELIMITER		" "
-#define CUTLINEDELIMITER	"..."LINEDELIMITER
+#define CUTLINEDELIMITER	"..." LINEDELIMITER
 #define SPECIALCHARS		'n'
 #define NEWPG			'`'
 #define TABCH			'~'
 #define RSSREFRESH		15
 #define FEEDTITLE		'n'
-#define FEEDTITLEDELIMITER	"        "
+#define FEEDTITLEDELIMITER	"                "
 #define ITEMTITLE		'y'
-#define ITEMTITLEDELIMITER	"        "
+#define ITEMTITLEDELIMITER	"        |        "
 #define ITEMDESCRIPTION		'n'
-#define ITEMDESCRIPTIONDELIMITER "        -        "
+#define ITEMDESCRIPTIONDELIMITER	"        ***        "
 #define NITEMSPERFEED		5
 #define STRIPHTMLTAGS		'y'
 #define UPPERCASETEXT		'n'
@@ -240,12 +240,19 @@
 #define CLOCK			'n'
 #define CFONTNAME		FONTNAME
 #define CFONTSIZE		"12"
-#define CFGCOLOR		"#aeaeaeff"	/* White but darker than text */
+#define CFGCOLOR		FGCOLOR
 #define CBGCOLOR		BGCOLOR
+#define SETCLOCKGRADIENTBG	'y'
+#define CBGCOLOR2		BGCOLOR2
 #define DISABLEPOPUPS		'n'
 #define PAUSEONMOUSEOVER	'y'
 #define DISABLELEFTCLICK	'n'
-#define MOUSEWHEELSCROLL	's'
+#define MOUSEWHEELSCROLL	'f'
+#ifndef G_OS_WIN32
+# define SFPICKERCLOSESWHENPOINTERLEAVES	'y'
+#else
+# define SFPICKERCLOSESWHENPOINTERLEAVES	'n'
+#endif
 #define ENABLEFEEDORDERING	'n'
 #define USEAUTHENTICATION	'n'
 #define USER			""
@@ -275,7 +282,7 @@ typedef enum {
 
 typedef enum {
 	RSS_FORMAT_UNDETERMINED,
-	RSS_1_0,	/* should use RDF or RSS_RDF instead ? */
+	RSS_1_0,	/* Should use RDF or RSS_RDF instead ? */
 	RSS_2_0,
 	RSS_ATOM
 } _rss_format;
@@ -322,7 +329,7 @@ typedef struct {
 	gint 		surf_width, surf_height;	/* Cairo image surface dimensions */
 	char		active_link[FILE_NAME_MAXLEN + 1];
 	int		mouse_x_in_drwa;
-	/* These flags are checked mainly by shift2left_callback() */
+	/* These flags are checked (mainly) by shift2left_callback() */
 	gboolean	suspend_rq;			/* Request for doing nothing */
 	gboolean	compute_rq;			/* Request for (re)computing everything (surface and win) */
 	gboolean	reload_rq;			/* Request for (re)loading resource */
@@ -339,7 +346,7 @@ typedef struct {
 
 typedef struct {
 	_resrc_type	type;				/* Text file or url */
-	_rss_format	format;				/* RSS 1.0, RSS 2.0 or Atom */
+	_rss_format	format;				/* RSS 1.0, RSS 2.0, or Atom */
 	char		id[FILE_NAME_MAXLEN + 1];	/* Local = file name or remote = feed url */
 	/* Apply only to url/rss */
 	_rss_format	rss_format;
@@ -358,7 +365,7 @@ typedef struct {
 #define PSW_MAXLEN		63
 #define AUTH_STR_MAXLEN		127
 
-/* Do we need both these auth/proxy structs and auth/proxy params? redundant... */
+/* TODO: Do we need both these auth/proxy structs and auth/proxy params? redundant - check this out */
 typedef struct {
 	gboolean	use_authentication;
 	char		user[USER_MAXLEN + 1];
@@ -392,6 +399,10 @@ typedef struct {
 	guint16		fg_color_alpha;
 	GdkColor	bg_color;
 	guint16		bg_color_alpha;
+	char		set_gradient_bg;
+	GdkColor	bg_color2;
+	guint16		bg_color2_alpha;
+	char		disable_screen_limits;
 	gint		win_x;
 	gint		win_y;
 	gint		win_w;
@@ -429,12 +440,16 @@ typedef struct {
 	guint16		clock_fg_color_alpha;
 	GdkColor	clock_bg_color;
 	guint16		clock_bg_color_alpha;
+	char		set_clock_gradient_bg;
+	GdkColor	clock_bg_color2;
+	guint16		clock_bg_color2_alpha;
 	char		disable_popups;
 	char		pause_on_mouseover;
 	char		disable_leftclick;
 	char		mouse_wheel_scroll;	/* Apply to s (speed) / f (feed) / n (none) */
+	char		sfpicker_closes_when_pointer_leaves;
 	char		enable_feed_ordering;
-/* Do we need both these auth/proxy structs and auth/proxy params? redundant... */
+/* TODO: Do we need both these auth/proxy structs and auth/proxy params? redundant - check this out */
 	char		use_authentication;
 	char		user[USER_MAXLEN + 1];
 	char		use_proxy;
@@ -467,10 +482,9 @@ typedef enum {
 	FEED_ERROR,
 	FEED_EMPTY,
 	FEED_UNPARSABLE,
-	RSS_NO_ITEM_ELEMENT,
-	ATOM_NO_ENTRY_ELEMENT,
+	FEED_NO_ITEM_OR_ENTRY_ELEMENT,
 	FEED_DOWNLOAD_ERROR,
-	FEED_FORMAT_ERROR,	/* rss 2.0 or atom format error */
+	FEED_FORMAT_ERROR,
 
 	RENDER_ERROR,
 	RENDER_NO_RESOURCE,
@@ -582,22 +596,14 @@ gint		get_clock_width(const Params *);
 
 /* tickr_feedparser.c */
 int		get_feed(Resource *, const Params *);
-int		parse_rss20_xml_file(FILE *, FILE *, const char *, FeedLinkAndOffset *link_and_offset,\
-			const Params *);
-/*int		parse_rss10_xml_file(FILE *, FILE *, const char *, FeedLinkAndOffset *link_and_offset,\
-			const Params *);*/
-int		parse_atom_xml_file(FILE *, FILE *, const char *, FeedLinkAndOffset *link_and_offset,\
+int		parse_xml_file(int, FILE *, FILE *, const char *, FeedLinkAndOffset *link_and_offset,\
 			const Params *);
 void		get_rss20_selected_elements1(xmlNode *, xmlDoc *);
-void		get_rss20_selected_elements2(xmlNode *, xmlDoc *, FILE *, FILE *,\
-			FeedLinkAndOffset *link_and_offset, const Params *);
-/*void		get_rss10_selected_elements1(xmlNode *, xmlDoc *);
-void		get_rss10_selected_elements2(xmlNode *, xmlDoc *, FILE *, FILE *,\
-*			FeedLinkAndOffset *link_and_offset, const Params *);*/
+void		get_rss10_selected_elements1(xmlNode *, xmlDoc *);
 void		get_atom_selected_elements1(xmlNode *, xmlDoc *);
-void		get_atom_selected_elements2(xmlNode *, xmlDoc *, FILE *, FILE *,\
-			FeedLinkAndOffset *link_and_offset, const Params *);
-int		get_feed_info(const char *, char *, char *, char *);
+void		get_feed_selected_elements2(int, xmlNode *, xmlDoc *, FILE *, FILE *,\
+			FeedLinkAndOffset *link_and_offset, const Params *prm);
+int		get_feed_info(int *, const char *, char *, char *, char *);
 void		get_xml_first_element(xmlNode *, xmlDoc *, char *, char *, int);
 
 /* tickr_feedpicker.c */
@@ -684,7 +690,7 @@ char		*get_proxy_auth_psw();
 char		*get_proxy_auth_str();
 
 /* tickr_quickfeedpicker.c */
-void		quick_feed_picker(int);
+void		quick_feed_picker();
 
 /* tickr_quicksetup.c */
 void		quick_setup(Params *);
