@@ -18,8 +18,8 @@
 
 #include "tickr.h"
 
-#define TIME_STR		"|%c%c:%c%c:%c%c"	/* At right = "|00:00:00" */
-#define TIME_STR_LENGTH		9
+#define CLOCK_DELIMITER		"|"	/* TODO: make as setting */
+#define TIME_STR		CLOCK_DELIMITER "%c%c:%c%c:%c%c"	/* At right = "|00:00:00"*/
 
 void display_time(const Params *prm)
 {
@@ -29,6 +29,7 @@ void display_time(const Params *prm)
 	int			layout_width, layout_height;
 	cairo_surface_t		*surf_clock;
 	cairo_t			*cr;
+	cairo_pattern_t		*cr_p;
 	float			shadow_k;
 	char			tmp[64];
 	time_t			time2;
@@ -46,9 +47,9 @@ void display_time(const Params *prm)
 		time2 = time(NULL);
 		if (prm->clock == 'l') {
 			str_n_cpy(tmp, ctime(&time2) + 11, 8);
-			str_n_cat(tmp, "|", 1);
+			str_n_cat(tmp, CLOCK_DELIMITER, strlen(CLOCK_DELIMITER));
 		} else if (prm->clock == 'r') {
-			str_n_cpy(tmp, "|", 1);
+			str_n_cpy(tmp, CLOCK_DELIMITER, strlen(CLOCK_DELIMITER));
 			str_n_cat(tmp, ctime(&time2) + 11, 8);
 		}
 
@@ -71,17 +72,41 @@ void display_time(const Params *prm)
 		cr = cairo_create(surf_clock);
 		/*
 		 * Render layout
-		 * (are used cairo operators ok ?)
 		 */
 		/* Draw background */
-		cairo_set_source_rgba(cr,
-			(float)prm->clock_bg_color.red / G_MAXUINT16,
-			(float)prm->clock_bg_color.green / G_MAXUINT16,
-			(float)prm->clock_bg_color.blue / G_MAXUINT16,
-			(float)prm->clock_bg_color_alpha / G_MAXUINT16
-			);
-		cairo_set_operator(cr, CAIRO_OPERATOR_SOURCE);
-		cairo_paint(cr);
+		if (get_params()->set_clock_gradient_bg == 'y') {
+			cr_p = cairo_pattern_create_linear(0.0, 0.0, 0.0, (float)env->drwa_height);
+			if (cairo_pattern_status(cr_p) == CAIRO_STATUS_SUCCESS) {
+				if (cairo_pattern_get_type(cr_p) == CAIRO_PATTERN_TYPE_LINEAR) {
+					cairo_pattern_add_color_stop_rgba(cr_p, 0.0,
+						(float)prm->clock_bg_color.red / G_MAXUINT16,
+						(float)prm->clock_bg_color.green / G_MAXUINT16,
+						(float)prm->clock_bg_color.blue / G_MAXUINT16,
+						(float)prm->clock_bg_color_alpha / G_MAXUINT16);
+					cairo_pattern_add_color_stop_rgba(cr_p, 1.0,
+						(float)prm->clock_bg_color2.red / (G_MAXUINT16),
+						(float)prm->clock_bg_color2.green / (G_MAXUINT16),
+						(float)prm->clock_bg_color2.blue / (G_MAXUINT16),
+						(float)prm->clock_bg_color_alpha / G_MAXUINT16);
+					cairo_set_source(cr, cr_p);
+					cairo_set_operator(cr, CAIRO_OPERATOR_SOURCE);
+					cairo_paint(cr);
+				} else
+					fprintf(STD_ERR, "display_time(): "
+						"cairo pattern type != linear (gradient)\n");
+			} else
+				fprintf(STD_ERR, "display_time(): "
+					"cairo_pattern_create_linear() error\n");
+			cairo_pattern_destroy(cr_p);
+		} else {
+			cairo_set_source_rgba(cr,
+				(float)prm->clock_bg_color.red / G_MAXUINT16,
+				(float)prm->clock_bg_color.green / G_MAXUINT16,
+				(float)prm->clock_bg_color.blue / G_MAXUINT16,
+				(float)prm->clock_bg_color_alpha / G_MAXUINT16);
+			cairo_set_operator(cr, CAIRO_OPERATOR_SOURCE);
+			cairo_paint(cr);
+		}
 		/* Draw foreground */
 		if (prm->shadow == 'y') {
 			/* Draw shadow */
@@ -91,15 +116,43 @@ void display_time(const Params *prm)
 				shadow_k = 0.0;
 			else
 				shadow_k = 1.0 - (float)prm->shadow_fx / 10.0;
-			cairo_set_source_rgba(cr,
-				(float)prm->clock_bg_color.red * shadow_k / G_MAXUINT16,
-				(float)prm->clock_bg_color.green * shadow_k / G_MAXUINT16,
-				(float)prm->clock_bg_color.blue * shadow_k / G_MAXUINT16,
-				(float)prm->clock_bg_color_alpha * shadow_k / G_MAXUINT16);
-			pango_cairo_update_layout(cr, p_layout);
-			cairo_move_to(cr, prm->shadow_offset_x, prm->shadow_offset_y);
-			cairo_set_operator(cr, CAIRO_OPERATOR_OVER);
-			pango_cairo_show_layout(cr, p_layout);
+			if (get_params()->set_gradient_bg == 'y') {
+				cr_p = cairo_pattern_create_linear(0.0, 0.0, 0.0, (float)env->drwa_height);
+				if (cairo_pattern_status(cr_p) == CAIRO_STATUS_SUCCESS) {
+					if (cairo_pattern_get_type(cr_p) == CAIRO_PATTERN_TYPE_LINEAR) {
+						cairo_pattern_add_color_stop_rgba(cr_p, 0.0,
+							(float)prm->clock_bg_color.red * shadow_k / G_MAXUINT16,
+							(float)prm->clock_bg_color.green * shadow_k / G_MAXUINT16,
+							(float)prm->clock_bg_color.blue * shadow_k / G_MAXUINT16,
+							(float)prm->clock_bg_color_alpha / G_MAXUINT16);
+						cairo_pattern_add_color_stop_rgba(cr_p, 1.0,
+							(float)prm->clock_bg_color2.red * shadow_k / (G_MAXUINT16),
+							(float)prm->clock_bg_color2.green * shadow_k / (G_MAXUINT16),
+							(float)prm->clock_bg_color2.blue * shadow_k / (G_MAXUINT16),
+							(float)prm->clock_bg_color_alpha / G_MAXUINT16);
+						cairo_set_source(cr, cr_p);
+						pango_cairo_update_layout(cr, p_layout);
+						cairo_move_to(cr, prm->shadow_offset_x, prm->shadow_offset_y);
+						cairo_set_operator(cr, CAIRO_OPERATOR_OVER);
+						pango_cairo_show_layout(cr, p_layout);
+					} else
+						fprintf(STD_ERR, "display_time(): "
+							"cairo pattern type != linear (gradient)\n");
+				} else
+					fprintf(STD_ERR, "display_time(): "
+						"cairo_pattern_create_linear() error\n");
+				cairo_pattern_destroy(cr_p);
+			} else {
+				cairo_set_source_rgba(cr,
+					(float)prm->clock_bg_color.red * shadow_k / G_MAXUINT16,
+					(float)prm->clock_bg_color.green * shadow_k / G_MAXUINT16,
+					(float)prm->clock_bg_color.blue * shadow_k / G_MAXUINT16,
+					(float)prm->clock_bg_color_alpha / G_MAXUINT16);
+				pango_cairo_update_layout(cr, p_layout);
+				cairo_move_to(cr, prm->shadow_offset_x, prm->shadow_offset_y);
+				cairo_set_operator(cr, CAIRO_OPERATOR_OVER);
+				pango_cairo_show_layout(cr, p_layout);
+			}
 		}
 		/* Draw text */
 		cairo_set_source_rgba(cr,
@@ -151,7 +204,7 @@ gint get_clock_width(const Params *prm)
 			pango_font_description_free(f_des);
 
 			for (i = '0'; i <= '9'; i++) {
-				snprintf(tmp, TIME_STR_LENGTH + 1, TIME_STR, i, i, i, i, i, i);
+				snprintf(tmp, /*time_str_len*/strlen(TIME_STR) + 1, TIME_STR, i, i, i, i, i, i);
 				pango_layout_set_text(p_layout, tmp, -1);
 				pango_layout_context_changed(p_layout);
 				pango_layout_get_pixel_size2(p_layout, &layout_width, &layout_height);
@@ -164,6 +217,7 @@ gint get_clock_width(const Params *prm)
 			width = (gint)layout_max_width;
 		}
 	} else
+		/* TODO: check that - something BUGGY here ???? */
 		width = 0;	/* Return 0 although if clock = none, actual widget width = 1 */
 	return width;
 }
