@@ -241,6 +241,7 @@ static int add_feed_to_flnode_and_list_store(Resource *resrc, GtkListStore *list
 	char	rss_feed_link[FILE_NAME_MAXLEN + 1];
 	char	rss_feed_ttl[32];
 	char	rank[FLIST_RANK_STR_LEN + 1];
+	int	unused;
 
 	str_n_cpy(resrc->id, (char *)gtk_entry_get_text(GTK_ENTRY(url_entry)), FILE_NAME_MAXLEN);
 	if (get_params()->enable_feed_ordering != 'y')
@@ -253,7 +254,7 @@ static int add_feed_to_flnode_and_list_store(Resource *resrc, GtkListStore *list
 	if ((rss_status = get_feed(resrc, get_params())) == OK) {
 		if (IS_FLIST(flist))
 			flist = f_list_last(flist);
-		if (get_feed_info(resrc->id, rss_feed_title, rss_feed_link, rss_feed_ttl) == OK)
+		if (get_feed_info(&unused, resrc->id, rss_feed_title, rss_feed_link, rss_feed_ttl) == OK)
 			/* Added url is set unselected. Is that OK ? */
 			flist = f_list_add_at_end(flist, resrc->id, rss_feed_title, FALSE, rank);
 		else
@@ -537,8 +538,16 @@ void get_new_url(Resource *resrc)
 			f_list_save_to_file(flist, NULL);
 			set_feed_list(flist);
 			build_feed_selection_from_feed_list();
-			if (IS_FLIST(get_feed_selection()) && response == GTK_RESPONSE_SELECTION)
-				first_feed();
+			if (IS_FLIST(get_feed_selection()) && response == GTK_RESPONSE_SELECTION) {
+				/*
+				 * NEW: Multiple selection mode: start reading selection with highlighted feed
+				 * - more exactly url in entry (if any) / first one otherwise.
+				 */
+				if ((f_index = f_list_search(get_feed_selection(), gtk_entry_get_text(GTK_ENTRY(url_entry)))) > -1)
+					set_feed_selection(f_list_nth(get_feed_selection(), f_index + 1));
+				else
+					first_feed();
+			}
 			if (IS_FLIST(flist_bak))
 				f_list_free_all(flist_bak);
 		} else {
