@@ -48,7 +48,7 @@ void remove_chunk_info(char **response)
 	*response = response2;
 }
 
-/* 'Quickly check feed format' (xml/rss2.0/atom), get shift to beginnig
+/* 'Quickly check feed format' (xml/rss2.0/rss1.0/atom), get shift to begining
  * and cut off trailing part. */
 static int format_quick_check(char *response, int *shift)
 {
@@ -70,24 +70,37 @@ static int format_quick_check(char *response, int *shift)
 			return FEED_FORMAT_ERROR;
 	} else {
 		i = 0;
-		while (strncmp(response + i, "<feed", 5) != 0 && response[i] != '\0')	/* atom */
+		while (strncmp(response + i, "<rdf:RDF", 8) != 0 && response[i] != '\0')	/* rss 1.0 */
 			i++;
 		if (response[i] != '\0') {
 			*shift = i;
-			while (strncmp(response + i, "/feed>", 6) != 0 && response[i] != '\0')
+			while (strncmp(response + i, "/rdf:RDF>", 9) != 0 && response[i] != '\0')
 				i++;
 			if (response[i] != '\0')
-				response[i + 6] = '\0';
+				response[i + 9] = '\0';
 			else
 				return FEED_FORMAT_ERROR;
-		} else
-			return FEED_FORMAT_ERROR;
+		} else {
+			i = 0;
+			while (strncmp(response + i, "<feed", 5) != 0 && response[i] != '\0')	/* atom */
+				i++;
+			if (response[i] != '\0') {
+				*shift = i;
+				while (strncmp(response + i, "/feed>", 6) != 0 && response[i] != '\0')
+					i++;
+				if (response[i] != '\0')
+					response[i + 6] = '\0';
+				else
+					return FEED_FORMAT_ERROR;
+			} else
+				return FEED_FORMAT_ERROR;
+		}
 	}
 	i = 0;
 	while (strncmp(response + i, "<?xml", 5) != 0 && response[i] != '\0')
 		i++;
 	if (response[i] != '\0')
-	*shift = i;
+		*shift = i;
 	return OK;
 }
 
@@ -133,8 +146,10 @@ int connect_with_url(sockt *sock, char *url)
 			connection_settings(PROXY_PAGE);
 		} else if (get_ticker_env()->selection_mode == SINGLE)
 			warning(FALSE, 2, "Can't connect to host: ", host);
-		else
+		else {
 			fprintf(STD_ERR, "Can't connect to host: %s\n", host);
+			fflush(STD_ERR);
+		}
 		if (++connect_fail_count >= CONNECT_FAIL_MAX) {
 			connect_fail_count = 0;
 			return CONNECT_TOO_MANY_ERRORS;
@@ -235,6 +250,7 @@ int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 #ifdef VERBOSE_OUTPUT		/* Only if verbose because notification only, nothing done. */
 				fprintf(STD_ERR, "No 'Transfer-Encoding' nor 'Content-Length' "
 					"header field in HTTP response\n");
+				fflush(STD_ERR);
 #endif
 			}
 			/* Quickly 'check format' (xml and rss2.0/atom stuff),
@@ -417,7 +433,7 @@ const char *build_http_request(const char *method, const char *path,\
 	snprintf(str, HTTP_REQUEST_MAXLEN,
 		"%s %s HTTP/1.1\r\n"	/* Start line with method and path */
 		"Host: %s\r\n"		/* Mandatory host header field */
-		"User-Agent: "APP_NAME"-"APP_VERSION_NUMBER"\r\n"
+		"User-Agent: " APP_NAME "-" APP_VERSION_NUMBER "\r\n"
 		"%s\r\n",		/* optional extra header field(s) */
 		method, path, host, rq_str);
 	return (const char *)str;
@@ -594,6 +610,7 @@ int get_http_chunk_size(const char *response)
 	if (tailptr == size_str) {
 		fprintf(STD_ERR, "Invalid hexadecimal value in HTTP chunk size: %s\n",
 			size_str);
+		fflush(STD_ERR);
 		return -1;
 	} else
 		return size;
