@@ -18,24 +18,6 @@
 
 #include "tickr.h"
 
-#ifdef G_OS_WIN32
-FILE			*stdout_fp, *stderr_fp;
-#endif
-static TickerEnv	*env;
-static Resource	*resrc;
-static FList		*feed_list;
-static FList		*feed_selection;
-static Params		*prm;
-static int		instance_id = 0;
-static gboolean	no_ui = FALSE;
-static int		shift_counter = 0;
-static GtkWidget	*popup_menu;
-static GtkAccelGroup	*popup_menu_accel_group;
-static int		popup_menu_accel_group_attached;
-static GtkWidget	*main_hbox, *vbox_ticker, *vbox_clock;
-static int		speed_up_flag = FALSE;
-static int		speed_down_flag = FALSE;
-
 #define START_PAUSE_TICKER_WHILE_OPENING\
 	int	suspend_rq_bak = env->suspend_rq;\
 	env->suspend_rq = TRUE;
@@ -56,14 +38,26 @@ static int		speed_down_flag = FALSE;
 	get_params()->disable_popups = disable_popups_bak;\
 	env->suspend_rq = suspend_rq_bak;
 
-/* IF_UI_ALLOWED now replace USE_GUI compile macro which has been there
- * and ***unused*** for ages and breaks compile. Plus it's a runtime variable */
 #define IF_UI_ALLOWED	if (!no_ui)
 
-/* Prototypes for a few static funcs */
-static void show_resource_info();
-static gint shift2left_callback();
-static void check_time_load_resource(check_time_mode);
+#ifdef G_OS_WIN32
+FILE			*stdout_fp, *stderr_fp;
+#endif
+
+static TickerEnv	*env;
+static Resource	*resrc;
+static FList		*feed_list;
+static FList		*feed_selection;
+static Params		*prm;
+static int		instance_id = 0;
+static gboolean	no_ui = FALSE;
+static int		shift_counter = 0;
+static GtkWidget	*popup_menu;
+static GtkAccelGroup	*popup_menu_accel_group;
+static int		popup_menu_accel_group_attached;
+static GtkWidget	*main_hbox, *vbox_ticker, *vbox_clock;
+static int		speed_up_flag = FALSE;
+static int		speed_down_flag = FALSE;
 
 TickerEnv *get_ticker_env()
 {
@@ -105,6 +99,11 @@ int get_instance_id()
 	return instance_id;
 }
 
+/* Prototypes for a few static funcs */
+static void	show_resource_info();
+static gint	shift2left_callback();
+static void	check_time_load_resource(check_time_mode);
+
 void check_main_win_always_on_top()
 {
 	if (prm->always_on_top == 'y')
@@ -358,6 +357,11 @@ static void show_resource_info()
 
 		for (i = 0; i < 7; i++)
 			gtk_misc_set_alignment(GTK_MISC(label[i]), 0, 0.5);
+#ifdef VERBOSE_OUTPUT
+		fprintf(STD_OUT, "Resource properties:\n"
+			"  Resource type: %s\n  Feed title: %s\n  Feed URL: %s\n",
+			tmp1, resrc->feed_title, resrc->id);
+#endif
 	} else if (resrc->type == RESRC_FILE) {
 		label[1] = gtk_label_new("Resource type:  ");
 		label[2] = gtk_label_new("File");
@@ -368,6 +372,10 @@ static void show_resource_info()
 
 		for (i = 0; i < 5; i++)
 			gtk_misc_set_alignment(GTK_MISC(label[i]), 0, 0.5);
+#ifdef VERBOSE_OUTPUT
+		fprintf(STD_OUT, "Resource Properties:\n"
+			"  Resource type: File\n  File name: %s\n", resrc->id);
+#endif
 	}
 
 	gtk_table_attach_defaults(GTK_TABLE(table), label[0], 1, 2, 0, 1);
@@ -398,7 +406,7 @@ static int easily_link_with_browser2()
 	int		exit_status = NO;
 
 	if ((browser_cmd_p = (char *)get_default_browser_from_win32registry()) != NULL) {
-		/* Find 1st str in browser_cmd */
+		/* Find 1st string in browser_cmd */
 		str_n_cpy(tmp, browser_cmd_p, 511);
 		for (i = 0, count = 0; i < strlen(tmp); i++) {
 			if (tmp[i] == '"') {
@@ -460,9 +468,6 @@ static int get_visible_link_and_rank(int position_x_in_drwa)
 static void open_link()
 {
 	char		tmp1[FILE_NAME_MAXLEN + 1], tmp2[FILE_NAME_MAXLEN + 1];
-/*#ifdef G_OS_WIN32
-	char		*tmp;
-#endif*/
 	char		*argv[32];	/* Up to 32 - 3 (prog name, url, NULL) args */
 	GPid		pid;
 	GError		*error = NULL;
@@ -538,9 +543,18 @@ static gint left_click_on_drawing_area(GtkWidget *widget, GdkEventButton *event_
 	widget = widget;
 	if (prm->disable_leftclick != 'y' && event_but->type == GDK_BUTTON_PRESS &&\
 			event_but->button == 1) {	/* 1 = mouse left button */
-		get_visible_link_and_rank(env->mouse_x_in_drwa);
-		open_link();
-		return TRUE;
+		/* NEW */
+		if (event_but->state & GDK_CONTROL_MASK) {
+			/* Do nothing so far */
+			return FALSE;
+		} else if (event_but->state & GDK_MOD1_MASK) {	/* = alt */
+			/* Do nothing so far */
+			return FALSE;
+		} else {
+			get_visible_link_and_rank(env->mouse_x_in_drwa);
+			open_link();
+			return TRUE;
+		}
 	} else
 		return FALSE;
 }
@@ -549,9 +563,18 @@ static gint right_click_on_drawing_area(GtkWidget *widget, GdkEventButton *event
 {
 	widget = widget;
 	if (event_but->type == GDK_BUTTON_PRESS && event_but->button == 3) {	/* 3 = mouse right button */
-		/* Popup main menu */
-		gtk_menu_popup(GTK_MENU(popup_menu), NULL, NULL, NULL, NULL, event_but->button, event_but->time);
-		return TRUE;
+		/* NEW */
+		if (event_but->state & GDK_CONTROL_MASK) {
+			quick_feed_picker();	/* NEW - OK ? */
+			return TRUE;
+		} else if (event_but->state & GDK_MOD1_MASK) {	/* = alt */
+			/* Do nothing so far */
+			return FALSE;
+		} else {
+			/* Popup main menu */
+			gtk_menu_popup(GTK_MENU(popup_menu), NULL, NULL, NULL, NULL, event_but->button, event_but->time);
+			return TRUE;
+		}
 	} else
 		return FALSE;
 }
@@ -572,8 +595,6 @@ static const char *get_win_title_text()
 	else
 		str_n_cpy(tmp1[i], "No resource", 256);
 	snprintf(tmp2[i], 64, "  |  %s-%s", APP_NAME, APP_VERSION_NUMBER);
-	/* which is better?
-	snprintf(tmp2[i], 64, "  |  %s", APP_NAME);*/
 	return (const char *)str_n_cat(tmp1[i], tmp2[i], 63);
 }
 
@@ -618,7 +639,6 @@ char *get_feed_extra_info(int rank)
 static const char *get_ticker_tooltip_text(int rank)
 {
 	static char	*tooltip_text = NULL;
-	/*gboolean	feed_extra_info = FALSE;*/
 
 	if (tooltip_text != NULL) {
 		l_str_free(tooltip_text);
@@ -628,14 +648,8 @@ static const char *get_ticker_tooltip_text(int rank)
 			(prm->item_title == 'n' && prm->item_description == 'y')) {
 		tooltip_text = l_str_new(get_feed_extra_info(rank));
 		if (tooltip_text[0] != '\0')
-			/*feed_extra_info = TRUE;
-		if (feed_extra_info)*/
 			tooltip_text = l_str_cat(tooltip_text, "\n\n");
-			/* which is better?
-			tooltip_text = l_str_cat(tooltip_text, "\n\n[ ");*/
 		tooltip_text = l_str_cat(tooltip_text, get_win_title_text());
-		/*if (feed_extra_info)
-			tooltip_text = l_str_cat(tooltip_text, " ]");*/
 		return tooltip_text;
 	} else
 		return get_win_title_text();
@@ -664,7 +678,7 @@ static gint mouse_over_drawing_area(GtkWidget *widget, GdkEvent *event)
 		if (prm->pause_on_mouseover == 'y') {
 			if (event->type == GDK_ENTER_NOTIFY)
 				env->suspend_rq = TRUE;
-			else /* USELESS: if (event->type == GDK_LEAVE_NOTIFY)*/
+			else
 				env->suspend_rq = FALSE;
 		}
 		if (event->type == GDK_ENTER_NOTIFY) {
@@ -702,10 +716,12 @@ static gint mouse_wheel_scroll_on_drawing_area(GtkWidget *widget, GdkEvent *even
 			return TRUE;
 		} else if (mouse_wheel_scroll == 'f') {
 			if (env->selection_mode == MULTIPLE) {
+				/* Seems buggy
 				if (event->scroll.direction == GDK_SCROLL_UP)
-					quick_feed_picker(GDK_SCROLL_UP);
+					next_feed2();
 				else if (event->scroll.direction == GDK_SCROLL_DOWN)
-					quick_feed_picker(GDK_SCROLL_DOWN);
+					previous_feed2();*/
+				quick_feed_picker();
 				env->suspend_rq = FALSE;
 			} else
 				warning(FALSE, 2, "Single selection mode\n",
@@ -824,15 +840,19 @@ static GtkWidget *get_popup_menu_menu(GtkWidget *win)
 	return gtk_item_factory_get_widget(item_factory, "<main>");
 }
 
-static gint update_win_dims()
+static gint update_win_dims_and_loc()
 {
+	/* Dimensions */
 	gtk_widget_set_size_request(env->drw_a, env->drwa_width, env->drwa_height);
 	gtk_widget_set_size_request(env->drwa_clock, env->drwa_clock_width, env->drwa_height);
 
-	gtk_widget_set_size_request(env->win, 0, 0);
+	gtk_widget_set_size_request(env->win, 1, 1);
 	gtk_window_resize(GTK_WINDOW(env->win), env->drwa_width + env->drwa_clock_width, env->drwa_height);
 
 	gtk_window_unmaximize(GTK_WINDOW(env->win));
+
+	/* Location */
+	gtk_window_move(GTK_WINDOW(env->win), prm->win_x, prm->win_y);
 	return TRUE;
 }
 
@@ -842,9 +862,8 @@ gboolean params_have_been_changed(Params *new_prm, int n_required_runs)
 	static Params	prm_bak;
 	static int	initial_runs = 0;
 
-	if (initial_runs < n_required_runs) {
+	if (initial_runs++ < n_required_runs) {
 		// 'fake params changes' are required at program startup
-		initial_runs++;
 		memcpy((void *)&prm_bak, (const void *)new_prm, sizeof(Params));
 		return TRUE;
 	} else if (memcmp((const void *)new_prm, (const void *)&prm_bak, sizeof(Params)) != 0) {
@@ -861,9 +880,8 @@ gboolean win_params_have_been_changed(Params *new_prm, int n_required_runs)
 	static int	initial_runs = 0;
 	gboolean	changes = FALSE;
 
-	if (initial_runs < n_required_runs) {
+	if (initial_runs++ < n_required_runs) {
 		/* 'fake params changes' are required at program startup */
-		initial_runs++;
 		memcpy((void *)prm_bak, (const void *)new_prm, sizeof(Params));
 		return TRUE;
 	} else if (strcmp(new_prm->font_n_s, prm_bak->font_n_s) != 0)
@@ -888,6 +906,7 @@ gboolean win_params_have_been_changed(Params *new_prm, int n_required_runs)
 		changes = TRUE;
 	else if (strcmp(new_prm->clock_font_n_s, prm_bak->clock_font_n_s) != 0)
 		changes = TRUE;
+	/* TODO: some other params need to be ckecked too */
 	if (changes == TRUE) {
 		memcpy((void *)prm_bak, (const void *)new_prm, sizeof(Params));
 		return TRUE;
@@ -903,7 +922,7 @@ static int compute_surface_and_win()
 	char 	fname[FONT_NAME_MAXLEN + 1], fsize[FONT_SIZE_MAXLEN + 1];
 	char	cfname[FONT_NAME_MAXLEN + 1], cfsize[FONT_SIZE_MAXLEN + 1];
 	gint	height1, height2;
-	int	size, render_exit_status, i;
+	int	size, render_exit_status, max_width, i;
 
 	/*
 	 * Compute font size from requested height if > 0
@@ -937,12 +956,13 @@ static int compute_surface_and_win()
 	/*
 	 * Compute ticker width
 	 */
-	if (prm->win_w >= DRWA_WIDTH_MIN && prm->win_w <= env->screen_w)
+	max_width = prm->disable_screen_limits == 'y' ? WIN_MAX_W : env->screen_w;
+	if (prm->win_w >= DRWA_WIDTH_MIN && prm->win_w <= max_width)
 		env->drwa_width = prm->win_w;
 	else if (prm->win_w < DRWA_WIDTH_MIN)
 		env->drwa_width = DRWA_WIDTH_MIN;
-	else if (prm->win_w > env->screen_w)
-		env->drwa_width = env->screen_w;
+	else if (prm->win_w > max_width)
+		env->drwa_width = max_width;
 	env->drwa_width -= (env->drwa_clock_width = get_clock_width(prm));
 	/*
 	 * Reset link_and_offset stuff
@@ -965,26 +985,27 @@ static int compute_surface_and_win()
 	env->c_surf = render_stream_to_surface(resrc->fp, resrc->link_and_offset, prm, &render_exit_status);
 	if (render_exit_status != OK && render_exit_status != RENDER_NO_RESOURCE) {
 		switch(render_exit_status) {
-			case RENDER_NULL_ENDINGSTR:
-				warning(FALSE, 1, "render_stream_to_surface(): ending string = NULL");
-				break;
-			case RENDER_GETLINE_ERROR:
-				warning(FALSE, 1, "render_stream_to_surface(): getline() error");
-				break;
-			case RENDER_LINE_TOO_LONG:
-				warning(FALSE, 1, "render_stream_to_surface(): line too long\n");
-				break;
-			case RENDER_CAIRO_IMAGE_SURFACE_TOO_WIDE:
-				big_error(RENDER_CAIRO_IMAGE_SURFACE_TOO_WIDE, 1, "render_stream_to_surface(): "
-					"cairo image surface too wide (> 32 K pixels)");
-				break;
-			case RENDER_CREATE_CAIRO_IMAGE_SURFACE_ERROR:
-				big_error(RENDER_CREATE_CAIRO_IMAGE_SURFACE_ERROR, 1, "render_stream_to_surface(): "
-					"can't create cairo image surface");
-				break;
-			default: warning(FALSE, 2, "render_stream_to_surface(): unknown error ",
-					itoa2(render_exit_status));
-				break;
+		case RENDER_NULL_ENDINGSTR:
+			warning(FALSE, 1, "render_stream_to_surface(): ending string = NULL");
+			break;
+		case RENDER_GETLINE_ERROR:
+			warning(FALSE, 1, "render_stream_to_surface(): getline() error");
+			break;
+		case RENDER_LINE_TOO_LONG:
+			warning(FALSE, 1, "render_stream_to_surface(): line too long\n");
+			break;
+		case RENDER_CAIRO_IMAGE_SURFACE_TOO_WIDE:
+			big_error(RENDER_CAIRO_IMAGE_SURFACE_TOO_WIDE, 1, "render_stream_to_surface(): "
+				"cairo image surface too wide (> 32 K pixels)");
+			break;
+		case RENDER_CREATE_CAIRO_IMAGE_SURFACE_ERROR:
+			big_error(RENDER_CREATE_CAIRO_IMAGE_SURFACE_ERROR, 1, "render_stream_to_surface(): "
+				"can't create cairo image surface");
+			break;
+		default:
+			warning(FALSE, 2, "render_stream_to_surface(): unknown error ",
+				itoa2(render_exit_status));
+			break;
 		}
 	}
 	if (env->c_surf == NULL)
@@ -1223,7 +1244,7 @@ static void quit_with_cli_info(tickr_error_code error_code)
 	free2(env);
 	free2(resrc);
 	free2(prm);
-	fprintf(STD_ERR, "Try '"APP_CMD" --help' for more information\n");
+	fprintf(STD_ERR, "Try '" APP_CMD " --help' for more information\n");
 	exit(error_code);
 }
 
@@ -1238,7 +1259,7 @@ static void print_help()
 
 static void print_version()
 {
-	fprintf(STD_OUT, APP_NAME" version "APP_VERSION_NUMBER"\n");
+	fprintf(STD_OUT, APP_NAME " version " APP_VERSION_NUMBER "\n");
 }
 
 static void print_license()
@@ -1346,7 +1367,7 @@ static gint swap_win32_logfiles()
 /* Question at program start-up about new feed list format conversion:
  * if version >= 0.6.2 and feed list exists and feed list backup doesn't
  * exist, create backup and convert to new format. */
-#define URL_LIST_BAK_FILE	URL_LIST_FILE"-bak"
+#define URL_LIST_BAK_FILE	URL_LIST_FILE "-bak"
 static void test_convert_local_feed_list()
 {
 	FILE	*fp1, *fp2;
@@ -1356,7 +1377,7 @@ static void test_convert_local_feed_list()
 	if (strncmp(APP_VERSION_NUMBER, "0.6.2", 5) >= 0)
 		if (g_file_test(get_datafile_full_name_from_name(URL_LIST_FILE), G_FILE_TEST_EXISTS) &&\
 				!g_file_test(get_datafile_full_name_from_name(URL_LIST_BAK_FILE), G_FILE_TEST_EXISTS))
-			if (question_win(APP_NAME" version 0.6.2 or later uses a new feed list format internally.\n"
+			if (question_win(APP_NAME " version 0.6.2 or later uses a new feed list format internally.\n"
 					"Do you wish your local feed list to be checked and eventually converted ?\n"
 					"(Doing this ONCE is strongly RECOMMENDED.)") == YES) {
 				fp1 = open_new_datafile_with_name(URL_LIST_FILE, "rb");
@@ -1403,9 +1424,10 @@ int main(int argc, char *argv[])
 	gtk_init(&argc, &argv);
 	LIBXML_TEST_VERSION
 #ifndef LIBXML_TREE_ENABLED
-# error Libxml2: tree support not compiled in
+# error "Libxml2: tree support not compiled in"
 #endif
 	xmlInitParser();
+
 	env = malloc2(sizeof(TickerEnv));
 	resrc = malloc2(sizeof(Resource));
 	prm = malloc2(sizeof(Params));
@@ -1425,7 +1447,7 @@ int main(int argc, char *argv[])
 	 * Toplevel window
 	 */
 	env->win = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-	gtk_window_set_title(GTK_WINDOW(env->win), APP_NAME"-"APP_VERSION_NUMBER);
+	gtk_window_set_title(GTK_WINDOW(env->win), APP_NAME "-" APP_VERSION_NUMBER);
 	gtk_container_set_border_width(GTK_CONTAINER(env->win), 0);
 	g_signal_connect(G_OBJECT(env->win), "delete_event", G_CALLBACK(gtk_main_quit), NULL);
 	g_signal_connect(G_OBJECT(env->win), "destroy", G_CALLBACK(gtk_widget_destroy), &(env->win));
@@ -1511,7 +1533,7 @@ int main(int argc, char *argv[])
 	fprintf(STD_OUT, "GDK visual: screen width = %d, screen height = %d, depth = %d\n",
 		env->screen_w, env->screen_h, env->depth);
 	if (no_ui)
-		warning(FALSE, 2, APP_NAME" will run with the 'no-ui' option.\n",
+		warning(FALSE, 2, APP_NAME " will run with the 'no-ui' option.\n",
 			"Opening of UI elements which can modify settings and/or \n"
 			"URL list/selection is disabled.");
 #endif
@@ -1535,14 +1557,6 @@ int main(int argc, char *argv[])
 		get_config_file_options(prm);
 	else
 		quick_setup(prm);
-
-/* NEW and experimental/unstable */
-#ifdef DOUBLE_LINE_TICKER
-	prm->feed_title = 'n';
-	prm->item_title = 'n';
-	prm->item_description = 'y';
-	prm->clock = 'n';
-#endif
 	n_options = 0;
 	n_resources = 0;
 	if (argc > 1) {
@@ -1669,7 +1683,7 @@ int main(int argc, char *argv[])
 	check_time_load_resource(TIME_RESET);
 	g_timeout_add_full(G_PRIORITY_DEFAULT, 1000, check_time_load_resource2, NULL, NULL);
 
-	g_timeout_add_full(G_PRIORITY_DEFAULT, 500, update_win_dims, NULL, NULL);
+	g_timeout_add_full(G_PRIORITY_DEFAULT, 500, update_win_dims_and_loc, NULL, NULL);
 
 	g_timeout_add_full(G_PRIORITY_DEFAULT, 100, update_everything, NULL, NULL);
 	/*
@@ -1684,13 +1698,17 @@ int main(int argc, char *argv[])
 	env->reload_rq = TRUE;
 
 	gtk_widget_show_all(env->win);
-	update_win_dims();
+	/* NEW - to get rid of starting 'ghost' square win - but is it effective ? */
+	gtk_widget_set_size_request(env->win, 1, 1);
+	gtk_window_resize(GTK_WINDOW(env->win), 1, 1);
 	gtk_main();
 	/*
 	 * Cleanup stuff
 	 */
 	if (resrc->fp != NULL)
 		fclose(resrc->fp);
+	if (resrc->fp_extra != NULL)
+		fclose(resrc->fp_extra);
 	xmlCleanupParser();
 #ifdef G_OS_WIN32
 	WSACleanup();
