@@ -100,7 +100,7 @@ static void get_layout_dims(GtkWidget *view, int *layout_width, int *layout_heig
 void help_win()
 {
 #ifndef G_OS_WIN32
-# define FONT			"DejaVu Sans Mono 8" /* 8 9 10 ok */
+# define FONT			"DejaVu Sans Mono 8" /* 8 9 10 OK */
 #else
 # define FONT			"Courier New 8"
 #endif
@@ -249,7 +249,7 @@ void about_win()
 	gtk_window_set_keep_above(GTK_WINDOW(get_ticker_env()->win), FALSE);
 
 	dialog = gtk_dialog_new_with_buttons(
-			"About "APP_NAME, GTK_WINDOW(get_ticker_env()->win),
+			"About " APP_NAME, GTK_WINDOW(get_ticker_env()->win),
 			GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 			NULL);
 
@@ -273,16 +273,16 @@ void about_win()
 	image = gtk_image_new_from_file(get_imagefile_full_name_from_name(TICKR_LOGO));
 	gtk_table_attach_defaults(GTK_TABLE(table), image, 0, 1, 0, 1);
 
-	label[0] = gtk_label_new("\n<b>"APP_NAME" version "APP_VERSION_NUMBER" - Feed Reader</b>");
+	label[0] = gtk_label_new("\n<b>" APP_NAME " version " APP_VERSION_NUMBER " - Feed Reader</b>");
 	gtk_label_set_use_markup(GTK_LABEL(label[0]), TRUE);
 	gtk_table_attach_defaults(GTK_TABLE(table), label[0], 0, 1, 1, 2);
 	label[1] = gtk_label_new("<small>Copyright (C) Emmanuel Thomas-Maurin 2009-2013</small>");
 	gtk_label_set_use_markup(GTK_LABEL(label[1]), TRUE);
 	gtk_table_attach_defaults(GTK_TABLE(table), label[1], 0, 1, 2, 3);
-	label[2] = gtk_label_new("<a href=\"mailto:"SUPPORT_EMAIL_ADDR"\">"SUPPORT_EMAIL_ADDR"</a>");
+	label[2] = gtk_label_new("<a href=\"mailto:" SUPPORT_EMAIL_ADDR "\">" SUPPORT_EMAIL_ADDR "</a>");
 	gtk_label_set_use_markup(GTK_LABEL(label[2]), TRUE);
 	gtk_table_attach_defaults(GTK_TABLE(table), label[2], 0, 1, 3, 4);
-	label[3] = gtk_label_new("<a href=\""WEBSITE_URL"\">"WEBSITE_URL"</a>");
+	label[3] = gtk_label_new("<a href=\"" WEBSITE_URL "\">" WEBSITE_URL "</a>");
 	gtk_label_set_use_markup(GTK_LABEL(label[3]), TRUE);
 	gtk_table_attach_defaults(GTK_TABLE(table), label[3], 0, 1, 4, 5);
 
