@@ -29,7 +29,10 @@ void set_default_options(Params *prm)
 	str_n_cpy(prm->font_n_s, tmp_font, FONT_MAXLEN);
 	get_gdk_color_from_hexstr(FGCOLOR, &prm->fg_color, &prm->fg_color_alpha);
 	get_gdk_color_from_hexstr(BGCOLOR, &prm->bg_color, &prm->bg_color_alpha);
+	prm->set_gradient_bg = SETGRADIENTBG;
+	get_gdk_color_from_hexstr(BGCOLOR2, &prm->bg_color2, &prm->bg_color2_alpha);
 
+	prm->disable_screen_limits = DISABLESCREENLIMITS;
 	prm->win_x = WIN_X;
 	prm->win_y = WIN_Y;
 	prm->win_w = get_ticker_env()->screen_w;	/* Instead of WIN_W; */
@@ -71,10 +74,10 @@ void set_default_options(Params *prm)
 	str_n_cpy(prm->open_link_args, OPENLINKARGS, FILE_NAME_MAXLEN);
 
 	prm->clock = CLOCK;
-	get_gdk_color_from_hexstr(CFGCOLOR, &prm->clock_fg_color,
-						&prm->clock_fg_color_alpha);
-	get_gdk_color_from_hexstr(CBGCOLOR, &prm->clock_bg_color,
-						&prm->clock_bg_color_alpha);
+	get_gdk_color_from_hexstr(CFGCOLOR, &prm->clock_fg_color, &prm->clock_fg_color_alpha);
+	get_gdk_color_from_hexstr(CBGCOLOR, &prm->clock_bg_color, &prm->clock_bg_color_alpha);
+	prm->set_clock_gradient_bg = SETCLOCKGRADIENTBG;
+	get_gdk_color_from_hexstr(CBGCOLOR2, &prm->clock_bg_color2, &prm->clock_bg_color2_alpha);
 	compact_font(tmp_font, CFONTNAME, CFONTSIZE);
 	str_n_cpy(prm->clock_font_n_s, tmp_font, FONT_MAXLEN);
 
@@ -82,6 +85,7 @@ void set_default_options(Params *prm)
 	prm->pause_on_mouseover = PAUSEONMOUSEOVER;
 	prm->disable_leftclick = DISABLELEFTCLICK;
 	prm->mouse_wheel_scroll = MOUSEWHEELSCROLL;
+	prm->sfpicker_closes_when_pointer_leaves = SFPICKERCLOSESWHENPOINTERLEAVES;
 	prm->enable_feed_ordering = ENABLEFEEDORDERING;
 
 	prm->use_authentication = USEAUTHENTICATION;
@@ -202,8 +206,8 @@ int get_name_value_from_option(Params *prm, const char *option)
 		return (exit_status = OPTION_INVALID);
 	}
 	/*
-	 * NEW: All *string* values are now saved inclosed in a pair of " or '.
-	 * When read, enclosing " or ' are removed, so backward compatibility is preserved.
+	 * All *string* values are saved inclosed in a pair of ". When read, enclosing " (or ')
+	 * are removed. (This also ensure backward compatibility with previous versions.)
 	 */
 	str_n_cpy(tmp, value, OPTION_MAXLEN);
 	if ((i = strlen(tmp) >= 2) && ((tmp[0] == '\"' && tmp[i - 1] == '\"') ||
@@ -241,18 +245,40 @@ int get_name_value_from_option(Params *prm, const char *option)
 						&prm->bg_color_alpha);
 			exit_status = OPTION_VALUE_INVALID;
 		}
+	} else if (strcmp(name, "setgradientbg") == 0) {
+		if (strcmp(value, "y") != 0 && strcmp(value, "n") != 0) {
+			fprintf(STD_ERR, "Invalid value: %s\n", option);
+			exit_status = OPTION_VALUE_INVALID;
+		} else
+			prm->set_gradient_bg = value[0];
+	} else if (strcmp(name, "bgcolor2") == 0) {
+		if (!get_gdk_color_from_hexstr(value, &prm->bg_color2,
+						&prm->bg_color2_alpha)) {
+			get_gdk_color_from_hexstr(BGCOLOR, &prm->bg_color2,
+						&prm->bg_color2_alpha);
+			exit_status = OPTION_VALUE_INVALID;
+		}
+	} else if (strcmp(name, "disablescreenlimits") == 0) {
+		if (strcmp(value, "y") != 0 && strcmp(value, "n") != 0) {
+			fprintf(STD_ERR, "Invalid value: %s\n", option);
+			exit_status = OPTION_VALUE_INVALID;
+		} else
+			prm->disable_screen_limits = value[0];
 	} else if (strcmp(name, "win_x") == 0)
 		prm->win_x = atoi(value);
 	else if (strcmp(name, "win_y") == 0)
 		prm->win_y = atoi(value);
-	else if (strcmp(name, "win_w") == 0)
+	else if (strcmp(name, "win_w") == 0) {
 		prm->win_w = atoi(value);
-	/*
-	 * If win_h is set and > 0, it will override requested font size
-	 * with computed one.
-	 */
-	else if (strcmp(name, "win_h") == 0) {
+		/* Same as 'full width' but from command line */
+		if (prm->win_w == 0)
+			prm->win_w = get_ticker_env()->screen_w;
+	} else if (strcmp(name, "win_h") == 0) {
 		prm->win_h = atoi(value);
+		/*
+		* If win_h is set and > 0, it will override requested font size
+		* with computed one.
+		*/
 		if (prm->win_h > 0 && prm->win_h < DRWA_HEIGHT_MIN)
 			prm->win_h = DRWA_HEIGHT_MIN;
 	} else if (strcmp(name, "windec") == 0) {
@@ -273,7 +299,6 @@ int get_name_value_from_option(Params *prm, const char *option)
 		prm->win_transparency = atoi(value);
 		if ((int)prm->win_transparency < 1) {
 			fprintf(STD_ERR, "Invalid value: %s - will be set to 1\n", option);
-			/*prm->win_transparency = 0.1; BUG */
 			prm->win_transparency = 1.0;
 			exit_status = OPTION_VALUE_INVALID;
 		} else if ((int)prm->win_transparency > 10) {
@@ -395,6 +420,19 @@ int get_name_value_from_option(Params *prm, const char *option)
 					&prm->clock_bg_color_alpha);
 			exit_status = OPTION_VALUE_INVALID;
 		}
+	} else if (strcmp(name, "setclockgradientbg") == 0) {
+		if (strcmp(value, "y") != 0 && strcmp(value, "n") != 0) {
+			fprintf(STD_ERR, "Invalid value: %s\n", option);
+			exit_status = OPTION_VALUE_INVALID;
+		} else
+			prm->set_clock_gradient_bg = value[0];
+	} else if (strcmp(name, "clockbgcolor2") == 0) {
+		if (!get_gdk_color_from_hexstr(value, &prm->clock_bg_color2,
+						&prm->clock_bg_color2_alpha)) {
+			get_gdk_color_from_hexstr(BGCOLOR, &prm->clock_bg_color2,
+						&prm->clock_bg_color2_alpha);
+			exit_status = OPTION_VALUE_INVALID;
+		}
 	} else if (strcmp(name, "disablepopups") == 0) {
 		if (strcmp(value, "y") != 0 && strcmp(value, "n") != 0) {
 			fprintf(STD_ERR, "Invalid value: %s\n", option);
@@ -420,6 +458,12 @@ int get_name_value_from_option(Params *prm, const char *option)
 			exit_status = OPTION_VALUE_INVALID;
 		} else
 			prm->mouse_wheel_scroll = value[0];
+	} else if (strcmp(name, "sfpickercloseswhenpointerleaves") == 0) {
+		if (strcmp(value, "y") != 0 && strcmp(value, "n") != 0) {
+			fprintf(STD_ERR, "Invalid value: %s\n", option);
+			exit_status = OPTION_VALUE_INVALID;
+		} else
+			prm->sfpicker_closes_when_pointer_leaves = value[0];
 	} else if (strcmp(name, "enablefeedordering") == 0) {
 		if (strcmp(value, "y") != 0 && strcmp(value, "n") != 0) {
 			fprintf(STD_ERR, "Invalid value: %s\n", option);
@@ -498,9 +542,7 @@ void save_to_config_file(const Params *prm)
 		split_font(prm->font_n_s, fname, fsize);
 		split_font(prm->clock_font_n_s, cfname, cfsize);
 		snprintf(tmp, 4 * 1024, "%s%s%s",
-			/*
-			 * NEW: All *string* values are now saved inclosed in a pair of " or '.
-			 * Here, we have replaced %s by \"%s\".
+			/* All *string* values are saved inclosed in a pair of ".
 			 */
 			"-delay=%d\n"
 			"-shiftsize=%d\n"
@@ -508,6 +550,9 @@ void save_to_config_file(const Params *prm)
 			"-fontsize=%d\n"
 			"-fgcolor=\"%s\"\n"
 			"-bgcolor=\"%s\"\n"
+			"-setgradientbg=%c\n"
+			"-bgcolor2=\"%s\"\n"
+			"-disablescreenlimits=%c\n"
 			"-win_x=%d\n"
 			"-win_y=%d\n"
 			"-win_w=%d\n"
@@ -518,10 +563,10 @@ void save_to_config_file(const Params *prm)
 			"-iconintaskbar=%c\n"
 			"-winsticky=%c\n"
 			"-shadow=%c\n"
-			"-shadowoffset_x=%d\n"
+			"-shadowoffset_x=%d\n",
 			"-shadowoffset_y=%d\n"
 			"-shadowfx=%d\n"
-			"-linedelimiter=\"%s\"\n",
+			"-linedelimiter=\"%s\"\n"
 			"-cutlinedelimiter=\"%s\"\n"
 			"-specialchars=%c\n"
 			"-newpgchar=%c\n"
@@ -538,16 +583,19 @@ void save_to_config_file(const Params *prm)
 			"-uppercasetext=%c\n"
 			"-homefeed=\"%s\"\n"
 			"-openlinkcmd=\"%s\"\n"
-			"-openlinkargs=\"%s\"\n"
+			"-openlinkargs=\"%s\"\n",
 			"-clock=%c\n"
 			"-clockfontname=\"%s\"\n"
-			"-clockfontsize=%d\n",
+			"-clockfontsize=%d\n"
 			"-clockfgcolor=\"%s\"\n"
 			"-clockbgcolor=\"%s\"\n"
+			"-setclockgradientbg=%c\n"
+			"-clockbgcolor2=\"%s\"\n"
 			"-disablepopups=%c\n"
 			"-pauseonmouseover=%c\n"
 			"-disableleftclick=%c\n"
 			"-mousewheelscroll=%c\n"
+			"-sfpickercloseswhenpointerleaves=%c\n"
 			"-enablefeedordering=%c\n"
 			"-useauth=%c\n"
 			"-user=\"%s\"\n"
@@ -563,6 +611,9 @@ void save_to_config_file(const Params *prm)
 			fname, atoi(fsize),
 			get_hexstr_from_gdk_color(&prm->fg_color, &prm->fg_color_alpha),
 			get_hexstr_from_gdk_color(&prm->bg_color, &prm->bg_color_alpha),
+			prm->set_gradient_bg,
+			get_hexstr_from_gdk_color(&prm->bg_color2, &prm->bg_color2_alpha),
+			prm->disable_screen_limits,
 			prm->win_x,
 			prm->win_y,
 			prm->win_w,
@@ -599,10 +650,13 @@ void save_to_config_file(const Params *prm)
 			atoi(cfsize),
 			get_hexstr_from_gdk_color(&prm->clock_fg_color, &prm->clock_fg_color_alpha),
 			get_hexstr_from_gdk_color(&prm->clock_bg_color, &prm->clock_bg_color_alpha),
+			prm->set_clock_gradient_bg,
+			get_hexstr_from_gdk_color(&prm->clock_bg_color2, &prm->clock_bg_color2_alpha),
 			prm->disable_popups,
 			prm->pause_on_mouseover,
 			prm->disable_leftclick,
 			prm->mouse_wheel_scroll,
+			prm->sfpicker_closes_when_pointer_leaves,
 			prm->enable_feed_ordering,
 			prm->use_authentication,
 			prm->user,
