@@ -34,6 +34,24 @@ static gint enter_key_pressed(GtkWidget *dialog2, GdkEventKey *event_key)
 		return FALSE;
 }
 
+static gint mouse_over_area(GtkWidget *widget, GdkEvent *event)
+{
+	static int	i = 0;
+
+	widget = widget;
+	if (get_params()->sfpicker_closes_when_pointer_leaves == 'y' &&\
+			event->type == GDK_LEAVE_NOTIFY && i == 0) {
+		i = 1;
+		return TRUE;
+	} else if (get_params()->sfpicker_closes_when_pointer_leaves == 'y' &&\
+			event->type == GDK_LEAVE_NOTIFY && i == 1) {
+		i = 0;
+		force_quit_dialog(dialog);
+		return TRUE;
+	} else
+		return FALSE;
+}
+
 /* Tree selection callback - get url */
 static gint tree_selection_changed(GtkTreeSelection *selection)
 {
@@ -94,7 +112,7 @@ static void fill_list_store_from_flnode(GtkListStore *list_store)
 }
 
 /* Actually ***selected feed*** picker */
-void quick_feed_picker(int up_or_down)
+void quick_feed_picker()
 {
 	GtkTreeView		*tree_view;
 	GtkListStore		*list_store;
@@ -103,8 +121,6 @@ void quick_feed_picker(int up_or_down)
 	GtkTreeSelection	*selection;
 	gint			response;
 
-	up_or_down = up_or_down;	/* Unused so far */
-
 	dialog = gtk_dialog_new_with_buttons(
 			"Selected Feed Picker", GTK_WINDOW(get_ticker_env()->win),
 			GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -114,7 +130,10 @@ void quick_feed_picker(int up_or_down)
 	gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_MOUSE);
 	gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
 	gtk_container_set_border_width(GTK_CONTAINER(dialog), 0);
-	gtk_widget_set_size_request(dialog, 450, 200);
+	gtk_widget_set_size_request(dialog, 600, 150);	/* NEW - OK ? - previously 450, 200 */
+	/* Not sure about that:
+	if (get_params()->sfpicker_closes_when_pointer_leaves == 'y')
+		gtk_window_set_decorated(GTK_WINDOW(dialog), FALSE);*/
 
 	sc_win = gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sc_win), GTK_POLICY_AUTOMATIC,
@@ -136,11 +155,11 @@ void quick_feed_picker(int up_or_down)
 	tree_view = GTK_TREE_VIEW(gtk_tree_view_new_with_model(GTK_TREE_MODEL(list_store)));
 	renderer1 = gtk_cell_renderer_text_new();
 	column1 = gtk_tree_view_column_new_with_attributes("Selected Feed Title", renderer1,
-			"text", COLUMN_STRING_TITLE, NULL);
+		"text", COLUMN_STRING_TITLE, NULL);
 	gtk_tree_view_append_column(tree_view, column1);
 	renderer2 = gtk_cell_renderer_text_new();
 	column2 = gtk_tree_view_column_new_with_attributes("Selected Feed URL", renderer2,
-			"text", COLUMN_STRING_URL, NULL);
+		"text", COLUMN_STRING_URL, NULL);
 	gtk_tree_view_append_column(tree_view, column2);
 	gtk_container_add(GTK_CONTAINER(sc_win), GTK_WIDGET(tree_view));
 
@@ -152,6 +171,7 @@ void quick_feed_picker(int up_or_down)
 	g_signal_connect(G_OBJECT(dialog), "delete_event", G_CALLBACK(force_quit_dialog), NULL);
 	g_signal_connect(G_OBJECT(selection), "changed", G_CALLBACK(tree_selection_changed), NULL);
 	g_signal_connect(G_OBJECT(tree_view), "row_activated", G_CALLBACK(double_click_on_tree_view), NULL);
+	g_signal_connect(G_OBJECT(tree_view), "leave-notify-event", G_CALLBACK(mouse_over_area), NULL);
 
 	gtk_widget_show_all(dialog);
 	if (IS_FLIST(flist) && (get_resource()->id)[0] != '\0')
