@@ -40,17 +40,11 @@ cairo_surface_t *render_stream_to_surface(FILE *fp, FeedLinkAndOffset *link_and_
 	PangoFontDescription	*f_des;
 	int			layout_width, layout_height;
 	cairo_t			*cr;
+	cairo_pattern_t		*cr_p;
 	float			shadow_k;
 	char			tmp[4];
 	int			i, j;
 
-/* NEW and experimental/unstable */
-#ifdef DOUBLE_LINE_TICKER
-	((Params *)prm)->feed_title = 'n';
-	((Params *)prm)->item_title = 'n';
-	((Params *)prm)->item_description = 'y';
-	((Params *)prm)->clock = 'n';
-#endif
 	*render_exit_status = OK;
 	env->stream_fully_read = FALSE;
 	/*
@@ -112,11 +106,8 @@ cairo_surface_t *render_stream_to_surface(FILE *fp, FeedLinkAndOffset *link_and_
 	env->surf_width = (gint)layout_width;
 	env->surf_height = (gint)layout_height;
 
-/* NEW and experimental/unstable */
-#ifdef DOUBLE_LINE_TICKER
-	env->surf_height *= 2;	/* x 2 now */
-#endif
 	if (env->surf_width > XPIXMAP_MAXWIDTH) {
+		g_object_unref(p_layout);
 		*render_exit_status = RENDER_CAIRO_IMAGE_SURFACE_TOO_WIDE;
 		return NULL;
 	}
@@ -133,17 +124,41 @@ cairo_surface_t *render_stream_to_surface(FILE *fp, FeedLinkAndOffset *link_and_
 	cr = cairo_create(env->c_surf);
 	/*
 	 * Render layout
-	 * (are used cairo operators OK ?)
 	 */
 	/* Draw background */
-	cairo_set_source_rgba(cr,
-		(float)prm->bg_color.red / G_MAXUINT16,
-		(float)prm->bg_color.green / G_MAXUINT16,
-		(float)prm->bg_color.blue / G_MAXUINT16,
-		(float)prm->bg_color_alpha / G_MAXUINT16
-		);
-	cairo_set_operator(cr, CAIRO_OPERATOR_SOURCE);
-	cairo_paint(cr);
+	if (get_params()->set_gradient_bg == 'y') {
+		cr_p = cairo_pattern_create_linear(0.0, 0.0, 0.0, (float)env->surf_height);
+		if (cairo_pattern_status(cr_p) == CAIRO_STATUS_SUCCESS) {
+			if (cairo_pattern_get_type(cr_p) == CAIRO_PATTERN_TYPE_LINEAR) {
+				cairo_pattern_add_color_stop_rgba(cr_p, 0.0,
+					(float)prm->bg_color.red / G_MAXUINT16,
+					(float)prm->bg_color.green / G_MAXUINT16,
+					(float)prm->bg_color.blue / G_MAXUINT16,
+					(float)prm->bg_color_alpha / G_MAXUINT16);
+				cairo_pattern_add_color_stop_rgba(cr_p, 1.0,
+					(float)prm->bg_color2.red / (G_MAXUINT16),
+					(float)prm->bg_color2.green / (G_MAXUINT16),
+					(float)prm->bg_color2.blue / (G_MAXUINT16),
+					(float)prm->bg_color_alpha / G_MAXUINT16);
+				cairo_set_source(cr, cr_p);
+				cairo_set_operator(cr, CAIRO_OPERATOR_SOURCE);
+				cairo_paint(cr);
+			} else
+				fprintf(STD_ERR, "render_stream_to_surface(): "
+					"Cairo pattern type != linear (gradient)\n");
+		} else
+			fprintf(STD_ERR, "render_stream_to_surface(): "
+				"Cairo_pattern_create_linear() error\n");
+		cairo_pattern_destroy(cr_p);
+	} else {
+		cairo_set_source_rgba(cr,
+			(float)prm->bg_color.red / G_MAXUINT16,
+			(float)prm->bg_color.green / G_MAXUINT16,
+			(float)prm->bg_color.blue / G_MAXUINT16,
+			(float)prm->bg_color_alpha / G_MAXUINT16);
+		cairo_set_operator(cr, CAIRO_OPERATOR_SOURCE);
+		cairo_paint(cr);
+	}
 	/* Draw foreground */
 	if (prm->shadow == 'y') {
 		/* Draw shadow */
@@ -153,15 +168,43 @@ cairo_surface_t *render_stream_to_surface(FILE *fp, FeedLinkAndOffset *link_and_
 			shadow_k = 0.0;
 		else
 			shadow_k = 1.0 - (float)prm->shadow_fx / 10.0;
-		cairo_set_source_rgba(cr,
-			(float)prm->bg_color.red * shadow_k / G_MAXUINT16,
-			(float)prm->bg_color.green * shadow_k / G_MAXUINT16,
-			(float)prm->bg_color.blue * shadow_k / G_MAXUINT16,
-			(float)prm->bg_color_alpha * shadow_k / G_MAXUINT16);
-		pango_cairo_update_layout(cr, p_layout);
-		cairo_move_to(cr, prm->shadow_offset_x, prm->shadow_offset_y);
-		cairo_set_operator(cr, CAIRO_OPERATOR_OVER);
-		pango_cairo_show_layout(cr, p_layout);
+		if (get_params()->set_gradient_bg == 'y') {
+			cr_p = cairo_pattern_create_linear(0.0, 0.0, 0.0, (float)env->surf_height);
+			if (cairo_pattern_status(cr_p) == CAIRO_STATUS_SUCCESS) {
+				if (cairo_pattern_get_type(cr_p) == CAIRO_PATTERN_TYPE_LINEAR) {
+					cairo_pattern_add_color_stop_rgba(cr_p, 0.0,
+						(float)prm->bg_color.red * shadow_k / G_MAXUINT16,
+						(float)prm->bg_color.green * shadow_k / G_MAXUINT16,
+						(float)prm->bg_color.blue * shadow_k / G_MAXUINT16,
+						(float)prm->bg_color_alpha / G_MAXUINT16);
+					cairo_pattern_add_color_stop_rgba(cr_p, 1.0,
+						(float)prm->bg_color2.red * shadow_k / (G_MAXUINT16),
+						(float)prm->bg_color2.green * shadow_k / (G_MAXUINT16),
+						(float)prm->bg_color2.blue * shadow_k / (G_MAXUINT16),
+						(float)prm->bg_color_alpha / G_MAXUINT16);
+					cairo_set_source(cr, cr_p);
+					pango_cairo_update_layout(cr, p_layout);
+					cairo_move_to(cr, prm->shadow_offset_x, prm->shadow_offset_y);
+					cairo_set_operator(cr, CAIRO_OPERATOR_OVER);
+					pango_cairo_show_layout(cr, p_layout);
+				} else
+					fprintf(STD_ERR, "render_stream_to_surface(): "
+						"Cairo pattern type != linear (gradient)\n");
+			} else
+				fprintf(STD_ERR, "render_stream_to_surface(): "
+					"Cairo_pattern_create_linear() error\n");
+			cairo_pattern_destroy(cr_p);
+		} else {
+			cairo_set_source_rgba(cr,
+				(float)prm->bg_color.red * shadow_k / G_MAXUINT16,
+				(float)prm->bg_color.green * shadow_k / G_MAXUINT16,
+				(float)prm->bg_color.blue * shadow_k / G_MAXUINT16,
+				(float)prm->bg_color_alpha / G_MAXUINT16);
+			pango_cairo_update_layout(cr, p_layout);
+			cairo_move_to(cr, prm->shadow_offset_x, prm->shadow_offset_y);
+			cairo_set_operator(cr, CAIRO_OPERATOR_OVER);
+			pango_cairo_show_layout(cr, p_layout);
+		}
 	}
 	/* Draw text */
 	cairo_set_source_rgba(cr,
@@ -173,34 +216,9 @@ cairo_surface_t *render_stream_to_surface(FILE *fp, FeedLinkAndOffset *link_and_
 	cairo_move_to(cr, 0, 0);
 	cairo_set_operator(cr, CAIRO_OPERATOR_OVER);
 	pango_cairo_show_layout(cr, p_layout);
-
-/* NEW and experimental/unstable */
-#ifdef DOUBLE_LINE_TICKER
-	/* Draw 2nd text line below */
-	/* We use clock font and colors at the moment, hmmm... */
-	f_des = pango_font_description_from_string((const char *)prm->clock_font_n_s);
-	pango_layout_set_font_description(p_layout, f_des);
-	pango_font_description_free(f_des);
-	pango_layout_context_changed(p_layout);
-
-	cairo_set_source_rgba(cr,
-		(float)prm->clock_fg_color.red / G_MAXUINT16,
-		(float)prm->clock_fg_color.green / G_MAXUINT16,
-		(float)prm->clock_fg_color.blue / G_MAXUINT16,
-		(float)prm->clock_fg_color_alpha / G_MAXUINT16);
-
-	for (i = 0; i < NFEEDLINKANDOFFSETMAX && (link_and_offset + i)->offset_in_surface > 0; i++) {
-		/*if ((link_and_offset + i )->offset_in_surface == ) {*/
-			pango_layout_set_text(p_layout, get_feed_extra_info(i + 1), -1);
-			pango_layout_context_changed(p_layout);	/* ???? */
-			pango_cairo_update_layout(cr, p_layout);
-			cairo_move_to(cr, (link_and_offset + i)->offset_in_surface, env->surf_height / 2);
-			cairo_set_operator(cr, CAIRO_OPERATOR_OVER);
-			pango_cairo_show_layout(cr, p_layout);
-		/*}*/
-	}
-#endif
-	/* Drawing done - return surface */
+	/*
+	 * Drawing done - return surface
+	 */
 	if (p_layout != NULL)
 		g_object_unref(p_layout);
 	cairo_destroy(cr);
@@ -322,7 +340,7 @@ char *stream_to_htext(FILE *fp, char *txt_str, PangoLayout *p_layout, const Para
 				}
 				c = tmp1[i];
 				k = 1;
-				if (c == '\n') {
+				if (c == '\n') {	/* tmp1 last char, because we use getline() / fgets(). */
 					str_n_cpy(&tmp2[j], prm->line_delimiter, OPTION_VALUE_MAXLEN);
 					j += strlen(prm->line_delimiter);
 					break;
