@@ -1,5 +1,5 @@
-/*	(re)configure xwin
- *	compile with: gcc -o win-config win-config.c -lX11
+/*	(Re)Configure xwin
+ *	Compile with: gcc -o win-config win-config.c -lX11
  */
 
 #include <X11/Xlib.h>
@@ -22,7 +22,7 @@ int main(int argc, char *argv[])
 	char		*displ_name = getenv("DISPLAY");
 
 	if ((displ = XOpenDisplay(displ_name)) != NULL) {
-		/* TODO: use XConfigureWindow() / XReconfigureWMWindow() */
+		/* TODO: Use XConfigureWindow() / XReconfigureWMWindow() */
 
 		screen_num = DefaultScreen(displ);
 		displ_w = DisplayWidth(displ, screen_num);
@@ -33,7 +33,7 @@ int main(int argc, char *argv[])
 		XCloseDisplay(displ);
 		return 0;
 	} else {
-		fprintf(stderr, "%s: cant connect to X server '%s'\n",
+		fprintf(stderr, "%s: Can't connect to X server '%s'\n",
 			argv[0], displ_name);
 		return 1;
 	}
