@@ -1,5 +1,5 @@
-/*	very basic xlib prog
- *	compile with: gcc -o xlib-prog xlib-prog.c -lX11
+/*	Very basic xlib prog
+ *	Compile with: gcc -o xlib-prog xlib-prog.c -lX11
  */
 
 #include <X11/Xlib.h>
@@ -47,7 +47,7 @@ int main(int argc, char *argv[])
 		XCloseDisplay(displ);
 		return 0;
 	} else {
-		fprintf(stderr, "%s: cant connect to X server '%s'\n",
+		fprintf(stderr, "%s: Can't connect to X server '%s'\n",
 			argv[0], displ_name);
 		return 1;
 	}
